==> rc-ui-lib-2.1.1.tgz: package/es/flex/Flex.js <==
var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
import React, { useContext, useMemo } from "react";
import classnames from "classnames";
import FlexContext from "./FlexContext";
import ConfigProviderContext from "../config-provider/ConfigProviderContext";
const Flex = (props) => {
  const _a = props, {
    direction,
    wrap,
    justify,
    align,
    gutter,
    style,
    className,
    children
  } = _a, rest = __objRest(_a, [
    "direction",
    "wrap",
    "justify",
    "align",
    "gutter",
    "style",
    "className",
    "children"
  ]);
  const {
    prefixCls,
    createNamespace
  } = useContext(ConfigProviderContext);
  const [bem] = createNamespace("flexbox", prefixCls);
  const getGutter = useMemo(() => Array.isArray(gutter) ? gutter : [gutter, 0], [gutter]);
  const rowStyle = __spreadValues(__spreadValues(__spreadValues({}, getGutter[0] > 0 ? {
    marginLeft: getGutter[0] / -2,
    marginRight: getGutter[0] / -2
  } : {}), getGutter[1] > 0 ? {
    marginTop: getGutter[1] / -2,
    marginBottom: getGutter[1] / 2
  } : {}), style);
  const wrapCls = classnames(className, bem([direction, wrap, justify ? `justify-${justify}` : false, align ? `align-${align}` : false]));
  return /* @__PURE__ */ React.createElement(FlexContext.Provider, {
    value: {
      gutter: getGutter
    }
  }, /* @__PURE__ */ React.createElement("div", _extends({
    className: wrapCls,
    style: rowStyle
  }, rest), children));
};
Flex.defaultProps = {
  gutter: 0
};
var stdin_default = Flex;
export {
  stdin_default as default
};

==> rc-ui-lib-2.1.3.tgz: package/es/flex/Flex.js <==
var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t)
        ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import React, { useContext, useMemo } from "react";
import classnames from "classnames";
import FlexContext from "./FlexContext";
import ConfigProviderContext from "../config-provider/ConfigProviderContext";
const Flex = (props) => {
  const _a = props, {
    direction,
    wrap,
    justify,
    align,
    gutter,
    style,
    className,
    children
  } = _a, rest = __objRest(_a, [
    "direction",
    "wrap",
    "justify",
    "align",
    "gutter",
    "style",
    "className",
    "children"
  ]);
  const {
    prefixCls,
    createNamespace
  } = useContext(ConfigProviderContext);
  const [bem] = createNamespace("flexbox", prefixCls);
  const getGutter = useMemo(() => Array.isArray(gutter) ? gutter : [gutter, 0], [gutter]);
  const rowStyle = __spreadValues(__spreadValues(__spreadValues({}, getGutter[0] > 0 ? {
    marginLeft: getGutter[0] / -2,
    marginRight: getGutter[0] / -2
  } : {}), getGutter[1] > 0 ? {
    marginTop: getGutter[1] / -2,
    marginBottom: getGutter[1] / 2
  } : {}), style);
  const wrapCls = classnames(className, bem([direction, wrap, justify ? `justify-${justify}` : false, align ? `align-${align}` : false]));
  return /* @__PURE__ */ React.createElement(FlexContext.Provider, {
    value: {
      gutter: getGutter
    }
  }, /* @__PURE__ */ React.createElement("div", _extends({
    className: wrapCls,
    style: rowStyle
  }, rest), children));
};
Flex.defaultProps = {
  gutter: 0
};
var stdin_default = Flex;
export {
  stdin_default as default
};
